@@ -5,26 +5,27 @@
 #'
 #' @export
 #' @return A row object of the context-appropriate type (label or data)
-#' @family compatability
+#' @family compatibility
 #' @examples
 #'
 #' rrow("ABC", c(1,2), c(3,2), format = "xx (xx.%)")
 #' rrow("")
 #'
-rrow = function(row.name = "", ..., format = NULL, indent = 0) {
-    vals = list(...)
+rrow <- function(row.name = "", ..., format = NULL, indent = 0, inset = 0L) {
+    vals <- list(...)
     if(is.null(row.name))
-        row.name = ""
+        row.name <- ""
     else if (!is(row.name, "character"))
-        stop() #row.name = as.character(row.name)
+        stop("row.name must be NULL or a character string")
     if(length(vals) == 0L) {
         LabelRow(lev = as.integer(indent),
                  label = row.name,
                  name = row.name,
-                 vis = TRUE)
+                 vis = TRUE,
+                 table_inset = 0L)
     } else {
-        csps = as.integer(sapply(vals, function(x) {
-            attr(x, "colspan") %||% 1L
+        csps <- as.integer(sapply(vals, function(x) {
+            attr(x, "colspan", exact = TRUE) %||% 1L
         }))
         ## we have to leave the formats on the cells and NOT the row unless we were
         ## already told to do so, because row formats get clobbered  when cbinding
@@ -35,7 +36,8 @@ rrow = function(row.name = "", ..., format = NULL, indent = 0) {
         DataRow(val = vals, lev = as.integer(indent), label = row.name,
                 name = row.name, ## XXX TODO
                 cspan = csps,
-                format = format)
+                format = format,
+                table_inset = as.integer(inset))
     }
 }
 
@@ -47,7 +49,7 @@ rrow = function(row.name = "", ..., format = NULL, indent = 0) {
 #'
 #' @inherit rrow return
 #' @export
-#' @family compatability
+#' @family compatibility
 #' @examples
 #' rrowl("a", c(1,2,3), format = "xx")
 #' rrowl("a", c(1,2,3), c(4,5,6), format = "xx")
@@ -63,76 +65,77 @@ rrow = function(row.name = "", ..., format = NULL, indent = 0) {
 #'
 #' rrowl(row.name = "row 1", c(1, 2), c(3,4))
 #' rrow(row.name = "row 2", c(1, 2), c(3,4))
-rrowl = function (row.name, ..., format = NULL, indent = 0)  {
+rrowl <- function(row.name, ..., format = NULL, indent = 0, inset = 0L)  {
     dots <- list(...)
     args_list <- c(list(row.name = row.name, format = format,
-        indent = indent), val = unlist(lapply(dots, as.list), recursive = FALSE))
+        indent = indent, inset = inset), val = unlist(lapply(dots, as.list), recursive = FALSE))
     do.call(rrow, args_list)
 }
 
 ## rcell moved to tt_afun_utils.R
 
 ##inefficient trash
-paste_em_n = function(lst, n, sep = ".") {
-    ret = lst[[1]]
+paste_em_n <- function(lst, n, sep = ".") {
+    ret <- lst[[1]]
     if(n > 1) {
         for(i in 2:n) {
-            ret = paste(ret, lst[[i]], sep = sep)
+            ret <- paste(ret, lst[[i]], sep = sep)
         }
     }
     ret
 }
 
 
-hrows_to_colinfo = function(rows) {
-    nr = length(rows)
+hrows_to_colinfo <- function(rows) {
+    nr <- length(rows)
     stopifnot(nr > 0)
-    cspans = lapply(rows, row_cspans)
-    vals = lapply(rows, function(x) unlist(row_values(x)))
-    unqvals = lapply(vals, unique)
-    formats = lapply(rows, obj_format)
-    counts = NULL
-    if( formats[ nr ] == "(N=xx)" ) { ## count row
-        counts = vals[[ nr ]]
-        vals = vals[ -nr ]
-        cspans = cspans[ -nr ]
-        nr = nr - 1
+    cspans <- lapply(rows, row_cspans)
+    vals <- lapply(rows, function(x) unlist(row_values(x)))
+    unqvals <- lapply(vals, unique)
+    formats <- lapply(rows, obj_format)
+    counts <- NULL
+    if(formats[nr] == "(N=xx)" ||
+         all(sapply(row_cells(rows[[nr]]), obj_format) == "(N=xx)")) { ## count row
+        counts <- vals[[nr]]
+        vals <- vals[-nr]
+        cspans <- cspans[-nr]
+        nr <- nr - 1
     }
     ## easiest case, one header row no counts. we're done
     ## XXX could one row but cspan ever make sense????
     ## I don't think so?
     if(nr == 1) { ## && all(cspans == 1L)) {
-        ret = manual_cols( unlist(vals[[ 1 ]] ) )
+        ret <- manual_cols(unlist(vals[[1]]))
         if(!is.null(counts)) {
-            col_counts(ret) = counts
-            disp_ccounts(ret) = TRUE
+            col_counts(ret) <- counts
+            disp_ccounts(ret) <- TRUE
         }
         return(ret)
     }
     ## second easiest case full repeated nestin
-    repvals = mapply(function(v, csp) rep(v, times = csp),
-                     v= vals, csp = cspans, SIMPLIFY=FALSE)
+    repvals <- mapply(function(v, csp) rep(v, times = csp),
+                     v = vals, csp = cspans, SIMPLIFY = FALSE)
 
     ## nr > 1 here
-    fullnest = TRUE
+    fullnest <- TRUE
     for(i in 2:nr) {
-        psted = paste_em_n(repvals, i-1)
-        spl = split(repvals[[i]], psted)
-        if( !all( sapply(spl, function(x)
-                 identical(x, spl[[1]]) ) ) ) {
+        psted <- paste_em_n(repvals, i - 1)
+        spl <- split(repvals[[i]], psted)
+        if(!all(sapply(spl, function(x)
+                 identical(x, spl[[1]])))) {
 
-            fullnest = FALSE
+            fullnest <- FALSE
             break
         }
     }
 
     ## if its full nesting we're done, so put
     ## the counts on as necessary and return.
-    if( fullnest ) {
-        ret = manual_cols(.lst = unqvals)
+    if(fullnest) {
+        ret <- manual_cols(.lst = unqvals)
         if(!is.null(counts)) {
-            col_counts(ret) = counts
-            disp_ccounts(ret) = TRUE
+            col_counts(ret) <- counts
+            disp_ccounts(ret) <- TRUE
         }
         return(ret)
     }
@@ -145,10 +148,10 @@ hrows_to_colinfo = function(rows) {
     ## based on the columns we actually want.
 
 
-    fullcolinfo = manual_cols(.lst = unqvals)
-    fullbusiness = names(collect_leaves(coltree(fullcolinfo)))
-    wanted = paste_em_n(repvals, nr)
-    wantcols = match(wanted, fullbusiness)
+    fullcolinfo <- manual_cols(.lst = unqvals)
+    fullbusiness <- names(collect_leaves(coltree(fullcolinfo)))
+    wanted <- paste_em_n(repvals, nr)
+    wantcols <- match(wanted, fullbusiness)
     stopifnot(all(!is.na(wantcols)))
 
 
@@ -159,11 +162,13 @@ hrows_to_colinfo = function(rows) {
 #' Create a header
 #'
 #' @inheritParams compat_args
-#' @param \dots row specifications (either as character vectors or the output from \code{\link{rrow}} or \code{\link{DataRow}}, \code{\link{LabelRow}}, etc.
+#' @param \dots row specifications (either as character vectors or the output
+#'   from \code{\link{rrow}} or \code{\link{DataRow}}, \code{\link{LabelRow}},
+#'   etc.
 #'
 #' @export
 #' @return a \code{InstantiatedColumnInfo} object.
-#' @family compatability
+#' @family compatibility
 #' @examples
 #'
 #' h1 <- rheader(c("A", "B", "C"))
@@ -177,11 +182,11 @@ hrows_to_colinfo = function(rows) {
 #'
 #' h2
 #'
-rheader = function(..., format = "xx", .lst = NULL) {
+rheader <- function(..., format = "xx", .lst = NULL) {
     if(!is.null(.lst))
-        args = .lst
+        args <- .lst
     else
-        args = list(...)
+        args <- list(...)
     rrows <- if (length(args) == 1 && !is(args[[1]], "TableRow")) {
         list(rrowl(row.name = NULL, val = args[[1]], format = format))
     } else if (are(args, "TableRow")) {
@@ -192,14 +197,14 @@ rheader = function(..., format = "xx", .lst = NULL) {
 }
 
 
-.char_to_hrows = function(hdr) {
-    nlfnd = grep("\n", hdr, fixed = TRUE)
+.char_to_hrows <- function(hdr) {
+    nlfnd <- grep("\n", hdr, fixed = TRUE)
     if(length(nlfnd) == 0)
         return(list(rrowl(NULL, hdr)))
 
     stopifnot(length(nlfnd) == length(hdr))
-    raw = strsplit(hdr, "\n", fixed = TRUE)
-    lens = unique(sapply(raw, length))
+    raw <- strsplit(hdr, "\n", fixed = TRUE)
+    lens <- unique(sapply(raw, length))
     stopifnot(length(lens) == 1L)
     lapply(seq(1, lens),
            function(i) {
@@ -214,13 +219,16 @@ rheader = function(..., format = "xx", .lst = NULL) {
 #'
 #' @inheritParams compat_args
 #' @inheritParams gen_args
-#' @param header Information defining the header (column strucure) of the table. This can be as row objects (legacy), character vectors or a \code{InstantiatedColumnInfo} object.
+#' @param header Information defining the header (column structure) of the table.
+#'   This can be as row objects (legacy), character vectors or a
+#'   \code{InstantiatedColumnInfo} object.
 #' @param \dots Rows to place in the table.
 #'
 #'
 #' @export
-#' @return a formal table object of the appropriate type (\code{ElementaryTable} or \code{TableTree})
-#' @family compatability
+#' @return a formal table object of the appropriate type (\code{ElementaryTable}
+#'   or \code{TableTree})
+#' @family compatibility
 #' @examples
 #'
 #' rtable(
@@ -303,45 +311,45 @@ rheader = function(..., format = "xx", .lst = NULL) {
 #'
 #' tbl2
 #'
-rtable = function(header, ..., format = NULL, hsep = default_hsep()) {
+rtable <- function(header, ..., format = NULL, hsep = default_hsep(),
+                   inset = 0L) {
     if(is.character(header))
-        header = .char_to_hrows(header) #list(rrowl(NULL, header))
+        header <- .char_to_hrows(header) #list(rrowl(NULL, header))
     if(is.list(header)) {
         if(are(header, "TableRow"))
-            colinfo = hrows_to_colinfo(header)
+            colinfo <- hrows_to_colinfo(header)
         else if(are(header, "list"))
-            colinfo = do.call(rheader, header)
+            colinfo <- do.call(rheader, header)
     } else if(is(header, "InstantiatedColumnInfo")) {
-        colinfo = header
+        colinfo <- header
     } else if (is(header, "TableRow")) {
-        colinfo = hrows_to_colinfo(list(header))
+        colinfo <- hrows_to_colinfo(list(header))
     } else {
         stop("problems")
 
     }
 
-    body = list(...)
+    body <- list(...)
     ## XXX this shouldn't be needed. hacky
     if(length(body) == 1 && is.list(body[[1]]))
-        body = body[[1]]
+        body <- body[[1]]
     if(are(body, "ElementaryTable") &&
        all(sapply(body, function(tb) {
            nrow(tb) == 1 && obj_name(tb) == ""
        }))) {
-        body = lapply(body, function(tb) tree_children(tb)[[1]])
+        body <- lapply(body, function(tb) tree_children(tb)[[1]])
     }
 
     TableTree(kids = body, format = format, cinfo = colinfo,
               labelrow = LabelRow(lev = 0L, label = "", vis = FALSE),
-              hsep = hsep)
+              hsep = hsep, inset = inset)
 }
 
 #' @rdname rtable
 #' @export
-rtablel = function (header, ..., format = NULL, hsep = default_hsep())
-{
+rtablel <- function(header, ..., format = NULL, hsep = default_hsep(), inset = 0L) {
     dots <- list(...)
-    args_list <- c(list(header = header, format = format, hsep = hsep), unlist(lapply(dots,
+    args_list <- c(list(header = header, format = format, hsep = hsep, inset = inset), unlist(lapply(dots,
         as.list), recursive = FALSE))
     do.call(rtable, args_list)
 }
@@ -356,12 +364,12 @@ rbindl_rtables <- function(x, gap = 0, check_headers = TRUE) {
     if(!check_headers)
         warning("check_headers = FALSE is no longer supported, ignoring.")
 
-    firstcols = col_info(x[[1]])
-    i = 1
+    firstcols <- col_info(x[[1]])
+    i <- 1
     while(no_colinfo(firstcols) &&
           i <= length(x)) {
               firstcols <- col_info(x[[i]])
-              i <- i+ 1
+              i <- i + 1
           }
 
     lapply(x, function(xi) chk_compat_cinfos(x[[1]], xi)) ##col_info(xi)))
@@ -374,12 +382,12 @@ rbindl_rtables <- function(x, gap = 0, check_headers = TRUE) {
 
     ## we used to check for xi not being a lable row, why?? XXX
     if(all(sapply(x, function(xi) {
-        (is(xi, "ElementaryTable") && !labelrow_visible(xi) )||
+        (is(xi, "ElementaryTable") && !labelrow_visible(xi)) ||
             is(xi, "TableRow")}))) { ## && !is(xi, "LabelRow")}))) {
         x <- unlist(lapply(x, function(xi) {
-            if(is(xi, "TableRow"))
+            if(is(xi, "TableRow")) {
                 xi
-            else {
+            } else {
                 lst <- tree_children(xi)
                 lapply(lst, indent,
                        by = indent_mod(xi))
@@ -435,7 +443,8 @@ setMethod("rbind", "VTableNodeInfo",
 })
 
 #' @exportMethod rbind2
-#' @rdname rbind
+#' @param y Second element to be rbound via `rbind2`
+#' @rdname int_methods
 setMethod("rbind2", c("VTableNodeInfo", "missing"),
           function(x, y) {
     TableTree(kids = list(x), cinfo = col_info(x), name = "rbind_root", label = "")
@@ -452,7 +461,7 @@ setMethod("rbind2", "VTableNodeInfo",
 
 
 
-combine_cinfo = function(..., new_total = NULL) {
+combine_cinfo <- function(..., new_total = NULL) {
     tabs <- list(...)
     chk_cbindable_many(tabs)
     cinfs <- lapply(tabs, col_info)
@@ -465,7 +474,7 @@ combine_cinfo = function(..., new_total = NULL) {
     if(is.null(new_total))
         new_total <- sum(newcounts)
     newexprs <- unlist(lapply(cinfs, col_exprs), recursive = FALSE)
-    newexargs <- unlist(lapply(cinfs, col_extra_args)) %||% vector("list", length(newcounts))
+    newexargs <- unlist(lapply(cinfs, col_extra_args), recursive = FALSE) %||% vector("list", length(newcounts))
     newdisp <- any(vapply(cinfs, disp_ccounts, NA))
     alltls <- lapply(cinfs, top_left)
     newtl <- character()
@@ -581,7 +590,7 @@ cbind_rtables <-  function(x, ...) {
 
 setGeneric("recurse_cbindl", function(x, cinfo, .list = NULL) standardGeneric("recurse_cbindl"))
 
-setMethod("recurse_cbindl", c(x ="VTableNodeInfo",
+setMethod("recurse_cbindl", c(x = "VTableNodeInfo",
                               cinfo = "NULL"),
           function(x, cinfo, .list  = NULL) {
     recurse_cbindl(x, cinfo = combine_cinfo(.list), .list = .list)
@@ -590,28 +599,33 @@ setMethod("recurse_cbindl", c(x ="VTableNodeInfo",
 setMethod("recurse_cbindl", c(x = "TableTree",
                              cinfo = "InstantiatedColumnInfo"),
           function(x, cinfo, .list = NULL) {
-    stopifnot(are(.list, class(x)))
+    stopifnot(are(.list, "VTableTree"))
     ## chk_cbindable(x, y)
-    xlst <- c(list(x), .list)
     xcont <- content_table(x)
     lstconts <- lapply(.list, content_table)
-    if(all(c(nrow(xcont) == 0,
-             vapply(lstconts, nrow, 1L) == 0))) {
+    lcontnrows <- vapply(lstconts, NROW, 1L)
+    unqnrcont <- unique(c(NROW(xcont), lcontnrows))
+    if(length(unqnrcont) > 1) {
+        stop("Got differing numbers of content rows [",
+             paste(unqnrcont, collapse = ", "),
+             "]. Unable to cbind these rtables")
+    }
 
-        cont = ElementaryTable(cinfo = cinfo)
+    if(unqnrcont == 0) {
+        cont <- ElementaryTable(cinfo = cinfo)
     } else {
-        cont = recurse_cbindl(xcont,
+        cont <- recurse_cbindl(xcont,
                              .list = lstconts,
                              cinfo = cinfo)
     }
 
-    kids = lapply(seq_along(tree_children(x)),
+    kids <- lapply(seq_along(tree_children(x)),
                   function(i) {
         recurse_cbindl(x = tree_children(x)[[i]],
                       cinfo = cinfo,
-                      .list <- lapply(.list, function(tt) tree_children(tt)[[i]]))
+                      .list = lapply(.list, function(tt) tree_children(tt)[[i]]))
     })
-    names(kids) = names(tree_children(x))
+    names(kids) <- names(tree_children(x))
     TableTree(kids = kids, labelrow = recurse_cbindl(tt_labelrow(x),
                                                     cinfo = cinfo,
                                                     .list = lapply(.list, tt_labelrow)),
@@ -629,16 +643,16 @@ setMethod("recurse_cbindl", c(x = "ElementaryTable",
  ##   chk_cbindable(x,y)
     if(nrow(x) == 0 &&
        all(vapply(.list, nrow, 1L) == 0)) {
-        col_info(x) = cinfo
+        col_info(x) <- cinfo
         return(x) ## this needs testing... I was right, it did #136
     }
-    kids = lapply(seq_along(tree_children(x)),
+    kids <- lapply(seq_along(tree_children(x)),
                   function(i) {
         recurse_cbindl(x = tree_children(x)[[i]],
                       cinfo = cinfo,
-                      .list <- lapply(.list, function(tt) tree_children(tt)[[i]]))
+                      .list = lapply(.list, function(tt) tree_children(tt)[[i]]))
     })
-    names(kids) = names(tree_children(x))
+    names(kids) <- names(tree_children(x))
 
 
      ElementaryTable(kids = kids,
@@ -660,8 +674,9 @@ setMethod("recurse_cbindl", c(x = "ElementaryTable",
     stopifnot(are(.list, class(x)))
 
     avars <- c(obj_avar(x), unlist(lapply(.list, obj_avar), recursive = FALSE))
+    avars <- avars[!is.na(avars)]
 
-    if(length(unique(avars))>1)
+    if(length(unique(avars)) > 1)
         stop("Got rows that don't analyze the same variable")
 
 
@@ -679,11 +694,12 @@ setMethod("recurse_cbindl", c(x = "ElementaryTable",
     for(i in seq_along(xlst)) {
         strt <- strtncols[i]
         end <- cumncols[i]
-        fullvy <- vy <- row_cells(xlst[[i]])
-        fullcspy <- cspy <- row_cspans(xlst[[i]])
+        ## full vars are here for debugging purposes
+        fullvy <- vy <- row_cells(xlst[[i]]) # nolint
+        fullcspy <- cspy <- row_cspans(xlst[[i]]) # nolint
 
         if(i > 1 &&
-           identical(rawvalues(vy[[1]]), rawvalues(lastval))&&
+           identical(rawvalues(vy[[1]]), rawvalues(lastval)) &&
          ##  cspy[1] == lastspn &&
            lastspn > 1) {
             vy <- vy[-1]
@@ -760,16 +776,19 @@ chk_compat_cinfos <- function(tt1, tt2) {
     }
 
     if (any(sapply(col_extra_args(ci2),
-                   function(x) length(x)>0)) &&
+                   function(x) length(x) > 0)) &&
         !identical(col_extra_args(ci1),
                    col_extra_args(ci2))) {
-        stop("Column structures not compatible: 2nd column structure has non-matching, non-null extra args")
+        stop("Column structures not compatible: 2nd column structure has ",
+             "non-matching, non-null extra args")
 
     }
 
     if(any(nzchar(top_left(ci1))) && any(nzchar(top_left(ci2))) &&
        !identical(top_left(ci1), top_left(ci2))) {
-        stop("Top-left materials not compatible: Got non-empty, non-matching top-left materials. Clear them using top_left(x)<-character() before binding to force compatibility.")
+        stop("Top-left materials not compatible: Got non-empty, non-matching ",
+             "top-left materials. Clear them using top_left(x)<-character() ",
+             "before binding to force compatibility.")
     }
     TRUE
 }
@@ -791,22 +810,26 @@ chk_compat_cinfos <- function(tt1, tt2) {
 #'
 #' @inherit rbindl_rtables return
 #'
-#' @note Label rows (ie a row with no data values, only a row.name) can only be inserted at positions which do not already contain a label row when there is a non-trivial nested row structure in \code{tbl}
+#' @note Label rows (ie a row with no data values, only a row.name) can only be
+#'   inserted at positions which do not already contain a label row when there
+#'   is a non-trivial nested row structure in \code{tbl}
 #' @examples
 #' o <- options(warn = 0)
-#' tbl <- basic_table() %>%
+#' lyt <- basic_table() %>%
 #'     split_cols_by("Species") %>%
-#'     analyze("Sepal.Length") %>%
-#'     build_table(iris)
+#'     analyze("Sepal.Length")
+#'     
+#' tbl <- build_table(lyt, iris)
 #'
 #' insert_rrow(tbl, rrow("Hello World"))
 #' insert_rrow(tbl, rrow("Hello World"), at = 2)
 #'
-#' tbl2 <- basic_table() %>%
+#' lyt2 <- basic_table() %>%
 #'     split_cols_by("Species") %>%
 #'     split_rows_by("Species") %>%
-#'     analyze("Sepal.Length") %>%
-#'     build_table(iris)
+#'     analyze("Sepal.Length")
+#'     
+#' tbl2 <- build_table(lyt2, iris)
 #'
 #' insert_rrow(tbl2, rrow("Hello World"))
 #' insert_rrow(tbl2, rrow("Hello World"), at = 2)
@@ -841,23 +864,23 @@ insert_rrow <- function(tbl, rrow, at = 1,
 }
 
 
-.insert_helper = function(tt, row, at, pos,
+.insert_helper <- function(tt, row, at, pos,
                           ascontent = FALSE) {
     islab <- is(row, "LabelRow")
     kids <- tree_children(tt)
     numkids <- length(kids)
     kidnrs <- sapply(kids, nrow)
     cumpos <- pos + cumsum(kidnrs)
-    contnr = if(is(tt, "TableTree"))
+    contnr <- if(is(tt, "TableTree"))
                  nrow(content_table(tt))
              else
                  0
     contnr <- contnr + as.numeric(labelrow_visible(tt))
 
 
-    totnr = nrow(tt)
-    endpos = pos + totnr
-    atend = !islab && endpos == at - 1
+    totnr <- nrow(tt)
+    endpos <- pos + totnr
+    atend <- !islab && endpos == at - 1
     if(at == pos + 1
        && islab) {
         if(labelrow_visible(tt))
@@ -867,12 +890,17 @@ insert_rrow <- function(tbl, rrow, at = 1,
     }
 
     if(numkids == 0) {
-        kids = list(row)
+        kids <- list(row)
     } else if (atend) {
         if(are(kids, "TableRow")) {
-            kids = c(kids, list(row))
+            kids <- c(kids, list(row))
         } else {
-            kids[[numkids]] = recurse_insert(kids[[numkids]], row =  row, at = at, pos = pos + contnr + sum(kidnrs[-numkids]), ascontent =  ascontent)
+            kids[[numkids]] <- recurse_insert(
+                kids[[numkids]],
+                row =  row,
+                at = at,
+                pos = pos + contnr + sum(kidnrs[-numkids]),
+                ascontent =  ascontent)
         }
     } else { #have >0 kids
         kidnrs <- sapply(kids, nrow)
@@ -884,25 +912,25 @@ insert_rrow <- function(tbl, rrow, at = 1,
         ## label rows go in the beginning of
         ##  one at at
         ind <- min(which((cumpos + !islab) >= at),
-                   numkids )
-        thekid  = kids[[ind]]
+                   numkids)
+        thekid <- kids[[ind]]
 
         if(is(thekid, "TableRow")) {
-            tt_level(row) = tt_level(thekid)
+            tt_level(row) <- tt_level(thekid)
             if(ind == 1) {
-                bef = integer()
-                aft = 1:numkids
+                bef <- integer()
+                aft <- 1:numkids
             } else if(ind == numkids) {
-                bef = 1:(ind -1)
-                aft = ind
+                bef <- 1:(ind - 1)
+                aft <- ind
             } else {
-                bef = 1:ind
-                aft = (ind + 1):numkids
+                bef <- 1:ind
+                aft <- (ind + 1):numkids
             }
             kids <- c(kids[bef], list(row),
                       kids[aft])
         } else { # kid is not a table row
-            newpos <- if(ind==1)
+            newpos <- if(ind == 1)
                           pos + contnr
                       else
                           cumpos[ind - 1]
@@ -922,10 +950,10 @@ insert_rrow <- function(tbl, rrow, at = 1,
 setGeneric("recurse_insert", function(tt, row, at, pos, ascontent = FALSE) standardGeneric("recurse_insert"))
 setMethod("recurse_insert", "TableTree",
           function(tt, row, at, pos, ascontent = FALSE) {
-    ctab = content_table(tt)
-    contnr = nrow(ctab)
-    contpos = pos + contnr
-    islab = is(row, "LabelRow")
+    ctab <- content_table(tt)
+    contnr <- nrow(ctab)
+    contpos <- pos + contnr
+    islab <- is(row, "LabelRow")
     ## this will NOT insert it as
     if((contnr > 0 || islab) &&
        contpos > at) {
@@ -933,7 +961,7 @@ setMethod("recurse_insert", "TableTree",
         return(tt)
     }
 
-    .insert_helper(tt, row, at = at, pos= pos + contnr,
+    .insert_helper(tt, row, at = at, pos = pos + contnr,
                    ascontent = ascontent)
 })
 
@@ -942,6 +970,3 @@ setMethod("recurse_insert", "ElementaryTable",
     .insert_helper(tt, row, at = at, pos = pos,
                    ascontent = FALSE)
 })
-
-
-
