@@ -63,7 +63,7 @@ test_that("vertical and horizontal pagination work", {
     hpag2 <- paginate_table(simple_tbl, lpp = 80, cpp = 23)
     expect_identical(hpag1, hpag2)
 
-    hpag3 <- paginate_table(simple_tbl, lpp = 80, cpp = 24)
+    hpag3 <- paginate_table(simple_tbl, lpp = 80, cpp = 24, verbose = TRUE)
     expect_equal(rep(2, 3),
                  sapply(hpag3, ncol))
 
@@ -110,7 +110,9 @@ test_that("vertical and horizontal pagination work", {
     expect_identical(tt[, 1:2, keep_titles = TRUE,
                         reindex_refs = FALSE], res[[1]])
 
-    res2 <- paginate_table(tt, lpp = 75, cpp = 45, verbose = TRUE)
+    ## this was lpp = 75, but manual line counting suggests that
+    ## was a bad test, enforcing an off-by-one error.
+    res2 <- paginate_table(tt, lpp = 76, cpp = 45, verbose = TRUE)
     expect_identical(length(res2), 6L)
     expect_identical(res2[[1]], tt[1:63, 1:2, keep_titles = TRUE,
                                    reindex_refs = FALSE])
@@ -132,6 +134,11 @@ test_that("vertical and horizontal pagination work", {
     expect_identical(nrow(res2b[[1]]), 59L)
     expect_identical(vapply(res2b, ncol, 1L), rep(3L, 4))
 
+    ## topleft perservation
+    top_left(tt) <- "hahaha I'm a topleft"
+    res3 <- paginate_table(tt, lpp = 75, cpp = 45)
+    expect_identical(top_left(tt), top_left(res3[[1]]))
+
 
 
     lyt2 <- basic_table() %>%
@@ -219,8 +226,8 @@ test_that("cell and column wrapping works in pagination", {
                        2L, 1L, 1L, 1L, 3L)) ## the 2 is row label wrap, 3s are cell wraps
 
     # propose_column_widths(matrix_form(tt_for_wrap, TRUE))
-    pg_tbl_w_clw <- paginate_table(tt_for_wrap, lpp = lpp_tmp, colwidths = clw)
-    pg_tbl_no_clw <- paginate_table(tt_for_wrap, lpp = lpp_tmp)
+    pg_tbl_w_clw <- paginate_table(tt_for_wrap, lpp = lpp_tmp, cpp = NULL, colwidths = clw)
+    pg_tbl_no_clw <- paginate_table(tt_for_wrap, lpp = lpp_tmp, cpp = NULL,  verbose = TRUE)
     res1 <- toString(matrix_form(pg_tbl_no_clw[[1]], TRUE))
     res2 <- toString(matrix_form(tt_for_wrap, TRUE))
 
@@ -230,13 +237,13 @@ test_that("cell and column wrapping works in pagination", {
 
 
     ## entire table takes exactly 25 lines when content is wrapped
-    result <- paginate_table(tt_for_wrap, colwidths = clw, lpp = 25L)
+    result <- paginate_table(tt_for_wrap, colwidths = clw, lpp = 25L, cpp = NULL)
     expect_identical(result[[1]], tt_for_wrap)
 
     ## paginating at 24 walks up
     ##  10 row too long with wrap -> 9 label row -> 8 ok
     ## paginates after row 8 (BOAA -> AGE-> Mean)
-    result2 <- paginate_table(tt_for_wrap, colwidths = clw, lpp = 24L)
+    result2 <- paginate_table(tt_for_wrap, colwidths = clw, lpp = 24L, cpp = NULL)
     expect_identical(sapply(result2, nrow),
                      c(8L, 3L))
     result_str <- toString(result[[1]], widths = clw)
@@ -290,15 +297,16 @@ test_that("Pagination works with section dividers", {
     ], ttlst[[1]])
 
     expect_identical(
-        export_as_txt(ttlst[[1]][7:8, keep_titles = TRUE]),
-        "big title\n\n——————————————\n       all obs\n——————————————\nMean    34.89 \n~~~~~~~~~~~~~~\nM             \n"
+        export_as_txt(ttlst[[1]][7:8, keep_titles = TRUE], hsep = "-", paginate = FALSE),
+        "big title\n\n--------------\n       all obs\n--------------\nMean    34.89 \n~~~~~~~~~~~~~~\nM             \n"
     )
 
     expect_identical(
-        paste0(export_as_txt(tail(ttlst[[1]], 1)), export_as_txt(head(ttlst[[2]], 1))),
+        paste0(export_as_txt(tail(ttlst[[1]], 1), hsep = "-", paginate = FALSE),
+               export_as_txt(head(ttlst[[2]], 1), hsep = "-" , paginate = FALSE)),
         paste0(
-            "big title\n\n——————————————\n       all obs\n——————————————\nMean    34.28 \n",
-            "big title\n\n———————————\n    all obs\n———————————\nU          \n"
+            "big title\n\n--------------\n       all obs\n--------------\nMean    34.28 \n",
+            "big title\n\n-----------\n    all obs\n-----------\nU          \n"
         )
     )
 })
