@@ -561,3 +561,29 @@ test_that("indent mod preserved when paginating between multi-analyses", {
     expect_equal(rdf$indent[2], #smoker row
                  0)
 })
+
+
+## https://github.com/insightsengineering/rtables/issues/634
+## problem was actually in formatters fixed there in PR #152
+test_that("export_as_txt works when there are newlines in column labels (naturally or after wrapping", {
+    tbl <- basic_table(show_colcounts = TRUE) %>%
+    split_cols_by("ACTARM") %>%
+    split_rows_by(
+      "PARAMCD",
+      labels_var = "PARAM",
+      split_fun = drop_split_levels
+    ) %>%
+    split_rows_by(
+      "AVISIT",
+      split_fun = drop_split_levels,
+      label_pos = "hidden"
+    ) %>%
+    split_cols_by_multivar(
+      vars = c("AVAL", "CHG"),
+      varlabels = c("Analysis Value", "Change from\nBaseline")
+    ) %>%
+    analyze_colvars(afun = mean) %>%
+    build_table(formatters::ex_adlb)
+
+    expect_silent({tmp <- export_as_txt(tbl, lpp = 20)})
+})
