@@ -24,8 +24,8 @@ test_that("rtable design decisions", {
   expect_identical(names(t1), c("A", "B"))
   expect_equal(dim(t1), c(1, 2))
   expect_identical(row.names(t1), "row 1")
-  expect_identical(as.vector(t1[1,1]), 1)
-  expect_identical(as.vector(t1[1,2]), 2)
+  expect_identical(as.vector(t1[1, 1]), 1)
+  expect_identical(as.vector(t1[1, 2]), 2)
 
   tbl <- rtable(
     header = c("Treatment\nN=100", "Comparison\nN=300"),
@@ -43,27 +43,27 @@ test_that("rtable design decisions", {
     expect_identical(names(tbl), c("Treatment", "Comparison"))
 
     ## replace once the colspan rows are uncommented
-    expect_equal(dim(tbl) , c(6, 2))
+    expect_equal(dim(tbl), c(6, 2))
 
   expect_identical(row.names(tbl), c("A", "B", "", "this is a very long section header", "estimate", "95% CI"))
 
-  expect_identical(as.vector(tbl[1,1]), c(104, .2))
-  expect_identical(as.vector(tbl[1,2]), c(100, .4))
+  expect_identical(as.vector(tbl[1, 1]), c(104, .2))
+  expect_identical(as.vector(tbl[1, 2]), c(100, .4))
 
-  expect_identical(as.vector(tbl[2,1]), c(23, .4))
-  expect_identical(as.vector(tbl[2,2]), c(43, .5))
+  expect_identical(as.vector(tbl[2, 1]), c(23, .4))
+  expect_identical(as.vector(tbl[2, 2]), c(43, .5))
 
-  expect_true(is.null(as.vector(tbl[3,1])))
-  expect_true(is.null(as.vector(tbl[3,2])))
+  expect_true(is.null(as.vector(tbl[3, 1])))
+  expect_true(is.null(as.vector(tbl[3, 2])))
 
-  expect_true(is.null(as.vector(tbl[4,1])))
-  expect_true(is.null(as.vector(tbl[4,2])))
+  expect_true(is.null(as.vector(tbl[4, 1])))
+  expect_true(is.null(as.vector(tbl[4, 2])))
 
-  expect_identical(as.vector(tbl[5,1]), 55.23)
-  expect_identical(as.vector(tbl[5,2]), 55.23)
+  expect_identical(as.vector(tbl[5, 1]), 55.23)
+  expect_identical(as.vector(tbl[5, 2]), 55.23)
 
-  expect_identical(as.vector(tbl[6,1]), c(44.8, 67.4))
-  expect_identical(as.vector(tbl[6,2]), c(44.8, 67.4))
+  expect_identical(as.vector(tbl[6, 1]), c(44.8, 67.4))
+  expect_identical(as.vector(tbl[6, 2]), c(44.8, 67.4))
 
   t3 <- rtable(
     header = "B",
@@ -87,10 +87,16 @@ test_that("multi-header tables work", {
     rrowl(row.name = "row 2", 4:1)
   )
     ## printing it works
-    t1
+   res <- toString(t1)
   expect_equal(nrow(t1), 2)
   expect_equal(ncol(t1), 4)
-  expect_equal(names(t1), c("A", "A", "B", "B"))
+    expect_equal(names(t1), c("A", "A", "B", "B"))
+
+    t2 <- rtable(header = rheader(
+                     rrow(NULL, rcell("A"), rcell("B")),
+                     rrow(NULL, rcell(50L, format = "(N=xx)"), rcell(70L, format = "(N=xx)"))),
+                 rrowl("row 1", 1:2))
+    expect_identical(col_counts(t2), c(50L, 70L))
 
 })
 
@@ -127,8 +133,8 @@ test_that("df_to_tt works", {
     expect_identical(dim(mttt), dim(mtcars))
     expect_identical(names(mttt), names(mtcars))
     expect_identical(row.names(mttt), row.names(mtcars))
-    expect_equal(lapply(1:nrow(mtcars), function(i) unclass(mtcars[i,])),
-                     unname(cell_values(mttt)), check.attributes=FALSE)
+    expect_equal(lapply(seq_along(mtcars[[1]]), function(i) unclass(mtcars[i, ])),
+                     unname(cell_values(mttt)), check.attributes = FALSE)
 })
 
 test_that("non-ref-rcell works", {
